==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/content/messages/uk/base.php <==
<?php

return [
    '<strong>Permalink</strong> to this post' => '@@@@',
    'Content' => 'Зміст',
    'Permalink' => '@@@@',
    '(Also visible to non-members of this space)' => '',
    '<strong>Confirm</strong> post deletion' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Move</strong> content' => '',
    'Add a member to notify' => '',
    'Add tag...' => '',
    'Archived' => '',
    'Attach Files' => '',
    'Back to stream' => '',
    'Cancel' => '',
    'Cancel Edit' => '',
    'Change to "Private"' => '',
    'Change to "Public"' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Confirm' => '',
    'Content Tag with invalid contentcontainer_id assigned.' => '',
    'Content has been moved to {spacename}' => '',
    'Content visibility' => '',
    'Could not delete content!' => '',
    'Could not find requested content!' => '',
    'Created at:' => '',
    'Created by me' => '',
    'Creation time' => '',
    'Delete' => '',
    'Do you really want to delete this post? All likes and comments will be lost!' => '',
    'Edit' => '',
    'Filter' => '',
    'I\'m involved' => '',
    'Invalid content id given!' => '',
    'Invalid request method!' => '',
    'Invalid space selection.' => '',
    'Last update' => '',
    'Last updated {time}' => '',
    'Load more' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'Move content' => '',
    'Move to archive' => '',
    'New Updates Available!' => '',
    'No matches with your selected filters!' => '',
    'No tags found for the given query' => '',
    'None' => '',
    'Nothing here yet!' => '',
    'Notify members' => '',
    'Pin to top' => '',
    'Pinned' => '',
    'Private' => '',
    'Public' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'Submit' => '',
    'Tag' => '',
    'Target Space' => '',
    'The author of this content is not allowed to create private content within the selected space.' => '',
    'The author of this content is not allowed to create public content within the selected space.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content can\'t be moved to its current space.' => '',
    'The content has been archived.' => '',
    'The content has been deleted.' => '',
    'The content has been unarchived.' => '',
    'The given name is already in use.' => '',
    'The module {moduleName} is not enabled on the selected target space.' => '',
    'This action is disabled!' => '',
    'This content type can\'t be moved due to a missing module-id setting.' => '',
    'This content type can\'t be moved.' => '',
    'This space is archived.' => '',
    'This space is not visible!' => '',
    'Topics' => '',
    'Turn off notifications' => '',
    'Turn on notifications' => '',
    'Unarchive' => '',
    'Unlock comments' => '',
    'Unpin' => '',
    'Updated' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'With attachments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
    'You do not have the permission to move this content to the given space.' => '',
    'You do not have the permission to move this content.' => '',
    'Your last edit state has been saved!' => '',
    'in' => '',
];

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/content/messages/uk/base.php <==
<?php

return [
    '<strong>Permalink</strong> to this post' => '@@@@',
    'Cancel' => 'Скасувати',
    'Confirm' => 'Підтвердити',
    'Content' => 'Зміст',
    'Delete' => 'Видалити',
    'Edit' => 'Редагувати',
    'Invalid request method!' => 'Невірний метод запиту!',
    'Permalink' => '@@@@',
    'Topics' => 'Теми',
    'Unarchive' => 'Розпакувати',
    '(Also visible to non-members of this space)' => '',
    '<strong>Confirm</strong> post deletion' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Move</strong> content' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Activated' => '',
    'Add a member to notify' => '',
    'Add tag...' => '',
    'Archived' => '',
    'Attach Files' => '',
    'Back to stream' => '',
    'Cancel Edit' => '',
    'Cannot notify the author.' => '',
    'Change to "Private"' => '',
    'Change to "Public"' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Configure' => '',
    'Content Tag with invalid contentcontainer_id assigned.' => '',
    'Content has been moved to {spacename}' => '',
    'Could not find requested content!' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Created by me' => '',
    'Creation time' => '',
    'Deleted' => '',
    'Do you really want to delete this post? All likes and comments will be lost!' => '',
    'Draft' => '',
    'Enable' => '',
    'Filter' => '',
    'Hidden' => '',
    'I\'m involved' => '',
    'Invalid content id given!' => '',
    'Invalid space selection.' => '',
    'Last update' => '',
    'Last updated {time}' => '',
    'Load more' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'Move content' => '',
    'Move to archive' => '',
    'New Updates Available!' => '',
    'No matches with your selected filters!' => '',
    'No tags found for the given query' => '',
    'None' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Nothing here yet!' => '',
    'Notify members' => '',
    'Pin to top' => '',
    'Pinned' => '',
    'Private' => '',
    'Public' => '',
    'Publish draft' => '',
    'Schedule publication' => '',
    'Scheduled at {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'Submit' => '',
    'Tag' => '',
    'Target Space' => '',
    'The author of this content is not allowed to create private content within the selected space.' => '',
    'The author of this content is not allowed to create public content within the selected space.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content can\'t be moved to its current space.' => '',
    'The content has been archived.' => '',
    'The content has been deleted.' => '',
    'The content has been successfully published.' => '',
    'The content has been unarchived.' => '',
    'The given name is already in use.' => '',
    'The module {moduleName} is not enabled on the selected target space.' => '',
    'This action is disabled!' => '',
    'This content type can\'t be moved due to a missing module-id setting.' => '',
    'This content type can\'t be moved.' => '',
    'This space is archived.' => '',
    'This space is not visible!' => '',
    'Turn off notifications' => '',
    'Turn on notifications' => '',
    'Unlock comments' => '',
    'Unpin' => '',
    'Updated' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'With attachments' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
    'You do not have the permission to move this content to the given space.' => '',
    'You do not have the permission to move this content.' => '',
    'Your last edit state has been saved!' => '',
    'in' => '',
];
